# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_bigquery.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16gcp/gcp_bigquery.proto\x12\x18oak9.tython.gcp.bigquery\x1a\x13shared/shared.proto\"J\n!BigqueryConnectionXAwsXAccessRole\x12\x13\n\x0biam_role_id\x18\x01 \x01(\t\x12\x10\n\x08identity\x18\x02 \x01(\t\"j\n\x16\x42igqueryConnectionXAws\x12P\n\x0b\x61\x63\x63\x65ss_role\x18\x01 \x01(\x0b\x32;.oak9.tython.gcp.bigquery.BigqueryConnectionXAwsXAccessRole\"\x87\x01\n\x18\x42igqueryConnectionXAzure\x12\x13\n\x0b\x61pplication\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x1a\n\x12\x63ustomer_tenant_id\x18\x03 \x01(\t\x12\x11\n\tobject_id\x18\x04 \x01(\t\x12\x14\n\x0credirect_uri\x18\x05 \x01(\t\">\n BigqueryConnectionXCloudResource\x12\x1a\n\x12service_account_id\x18\x01 \x01(\t\"L\n\x1f\x42igqueryConnectionXCloudSpanner\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\x17\n\x0fuse_parallelism\x18\x02 \x01(\x08\"L\n&BigqueryConnectionXCloudSqlXCredential\x12\x10\n\x08password\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\"\xa8\x01\n\x1b\x42igqueryConnectionXCloudSql\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\x13\n\x0binstance_id\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12T\n\ncredential\x18\x04 \x01(\x0b\x32@.oak9.tython.gcp.bigquery.BigqueryConnectionXCloudSqlXCredential\"M\n\x1b\x42igqueryConnectionXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa0\x05\n\x12\x42igqueryConnection\x12\x15\n\rconnection_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x15\n\rfriendly_name\x18\x03 \x01(\t\x12\x16\n\x0ehas_credential\x18\x04 \x01(\x08\x12\n\n\x02id\x18\x05 \x01(\t\x12\x10\n\x08location\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12=\n\x03\x61ws\x18\t \x01(\x0b\x32\x30.oak9.tython.gcp.bigquery.BigqueryConnectionXAws\x12\x41\n\x05\x61zure\x18\n \x01(\x0b\x32\x32.oak9.tython.gcp.bigquery.BigqueryConnectionXAzure\x12R\n\x0e\x63loud_resource\x18\x0b \x01(\x0b\x32:.oak9.tython.gcp.bigquery.BigqueryConnectionXCloudResource\x12P\n\rcloud_spanner\x18\x0c \x01(\x0b\x32\x39.oak9.tython.gcp.bigquery.BigqueryConnectionXCloudSpanner\x12H\n\tcloud_sql\x18\r \x01(\x0b\x32\x35.oak9.tython.gcp.bigquery.BigqueryConnectionXCloudSql\x12G\n\x08timeouts\x18\x0e \x01(\x0b\x32\x35.oak9.tython.gcp.bigquery.BigqueryConnectionXTimeouts\x12\x37\n\rresource_info\x18\x0f \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"`\n&BigqueryConnectionIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x9f\x02\n\x1c\x42igqueryConnectionIamBinding\x12\x15\n\rconnection_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0f\n\x07members\x18\x05 \x03(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12S\n\tcondition\x18\x08 \x01(\x0b\x32@.oak9.tython.gcp.bigquery.BigqueryConnectionIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"_\n%BigqueryConnectionIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x9c\x02\n\x1b\x42igqueryConnectionIamMember\x12\x15\n\rconnection_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0e\n\x06member\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12R\n\tcondition\x18\x08 \x01(\x0b\x32?.oak9.tython.gcp.bigquery.BigqueryConnectionIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbf\x01\n\x1b\x42igqueryConnectionIamPolicy\x12\x15\n\rconnection_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"K\n+BigqueryDataTransferConfigXEmailPreferences\x12\x1c\n\x14\x65nable_failure_email\x18\x01 \x01(\x08\"s\n*BigqueryDataTransferConfigXScheduleOptions\x12\x1f\n\x17\x64isable_auto_scheduling\x18\x01 \x01(\x08\x12\x10\n\x08\x65nd_time\x18\x02 \x01(\t\x12\x12\n\nstart_time\x18\x03 \x01(\t\"G\n*BigqueryDataTransferConfigXSensitiveParams\x12\x19\n\x11secret_access_key\x18\x01 \x01(\t\"U\n#BigqueryDataTransferConfigXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xdb\x06\n\x1a\x42igqueryDataTransferConfig\x12 \n\x18\x64\x61ta_refresh_window_days\x18\x01 \x01(\x01\x12\x16\n\x0e\x64\x61ta_source_id\x18\x02 \x01(\t\x12\x1e\n\x16\x64\x65stination_dataset_id\x18\x03 \x01(\t\x12\x10\n\x08\x64isabled\x18\x04 \x01(\x08\x12\x14\n\x0c\x64isplay_name\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x10\n\x08location\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12!\n\x19notification_pubsub_topic\x18\t \x01(\t\x12P\n\x06params\x18\n \x03(\x0b\x32@.oak9.tython.gcp.bigquery.BigqueryDataTransferConfig.ParamsEntry\x12\x0f\n\x07project\x18\x0b \x01(\t\x12\x10\n\x08schedule\x18\x0c \x01(\t\x12\x1c\n\x14service_account_name\x18\r \x01(\t\x12`\n\x11\x65mail_preferences\x18\x0e \x01(\x0b\x32\x45.oak9.tython.gcp.bigquery.BigqueryDataTransferConfigXEmailPreferences\x12^\n\x10schedule_options\x18\x0f \x01(\x0b\x32\x44.oak9.tython.gcp.bigquery.BigqueryDataTransferConfigXScheduleOptions\x12^\n\x10sensitive_params\x18\x10 \x01(\x0b\x32\x44.oak9.tython.gcp.bigquery.BigqueryDataTransferConfigXSensitiveParams\x12O\n\x08timeouts\x18\x11 \x01(\x0b\x32=.oak9.tython.gcp.bigquery.BigqueryDataTransferConfigXTimeouts\x12\x37\n\rresource_info\x18\x12 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"P\n&BigqueryDatasetXAccessXDatasetXDataset\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\"\x89\x01\n\x1e\x42igqueryDatasetXAccessXDataset\x12\x14\n\x0ctarget_types\x18\x01 \x03(\t\x12Q\n\x07\x64\x61taset\x18\x02 \x01(\x0b\x32@.oak9.tython.gcp.bigquery.BigqueryDatasetXAccessXDatasetXDataset\"W\n\x1b\x42igqueryDatasetXAccessXView\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x10\n\x08table_id\x18\x03 \x01(\t\"\x8c\x02\n\x16\x42igqueryDatasetXAccess\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12\x16\n\x0egroup_by_email\x18\x02 \x01(\t\x12\x0c\n\x04role\x18\x03 \x01(\t\x12\x15\n\rspecial_group\x18\x04 \x01(\t\x12\x15\n\ruser_by_email\x18\x05 \x01(\t\x12I\n\x07\x64\x61taset\x18\x06 \x01(\x0b\x32\x38.oak9.tython.gcp.bigquery.BigqueryDatasetXAccessXDataset\x12\x43\n\x04view\x18\x07 \x01(\x0b\x32\x35.oak9.tython.gcp.bigquery.BigqueryDatasetXAccessXView\"F\n.BigqueryDatasetXDefaultEncryptionConfiguration\x12\x14\n\x0ckms_key_name\x18\x01 \x01(\t\"J\n\x18\x42igqueryDatasetXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xf1\x05\n\x0f\x42igqueryDataset\x12\x15\n\rcreation_time\x18\x01 \x01(\x01\x12\x12\n\ndataset_id\x18\x02 \x01(\t\x12\'\n\x1f\x64\x65\x66\x61ult_partition_expiration_ms\x18\x03 \x01(\x01\x12#\n\x1b\x64\x65\x66\x61ult_table_expiration_ms\x18\x04 \x01(\x01\x12\"\n\x1a\x64\x65lete_contents_on_destroy\x18\x05 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x0c\n\x04\x65tag\x18\x07 \x01(\t\x12\x15\n\rfriendly_name\x18\x08 \x01(\t\x12\n\n\x02id\x18\t \x01(\t\x12\x45\n\x06labels\x18\n \x03(\x0b\x32\x35.oak9.tython.gcp.bigquery.BigqueryDataset.LabelsEntry\x12\x1a\n\x12last_modified_time\x18\x0b \x01(\x01\x12\x10\n\x08location\x18\x0c \x01(\t\x12\x0f\n\x07project\x18\r \x01(\t\x12\x11\n\tself_link\x18\x0e \x01(\t\x12@\n\x06\x61\x63\x63\x65ss\x18\x0f \x03(\x0b\x32\x30.oak9.tython.gcp.bigquery.BigqueryDatasetXAccess\x12r\n default_encryption_configuration\x18\x10 \x01(\x0b\x32H.oak9.tython.gcp.bigquery.BigqueryDatasetXDefaultEncryptionConfiguration\x12\x44\n\x08timeouts\x18\x11 \x01(\x0b\x32\x32.oak9.tython.gcp.bigquery.BigqueryDatasetXTimeouts\x12\x37\n\rresource_info\x18\x12 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"O\n%BigqueryDatasetAccessXDatasetXDataset\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\"\x87\x01\n\x1d\x42igqueryDatasetAccessXDataset\x12\x14\n\x0ctarget_types\x18\x01 \x03(\t\x12P\n\x07\x64\x61taset\x18\x02 \x01(\x0b\x32?.oak9.tython.gcp.bigquery.BigqueryDatasetAccessXDatasetXDataset\"@\n\x1e\x42igqueryDatasetAccessXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"V\n\x1a\x42igqueryDatasetAccessXView\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x10\n\x08table_id\x18\x03 \x01(\t\"\xef\x03\n\x15\x42igqueryDatasetAccess\x12\x1a\n\x12\x61pi_updated_member\x18\x01 \x01(\x08\x12\x12\n\ndataset_id\x18\x02 \x01(\t\x12\x0e\n\x06\x64omain\x18\x03 \x01(\t\x12\x16\n\x0egroup_by_email\x18\x04 \x01(\t\x12\x12\n\niam_member\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x0c\n\x04role\x18\x08 \x01(\t\x12\x15\n\rspecial_group\x18\t \x01(\t\x12\x15\n\ruser_by_email\x18\n \x01(\t\x12H\n\x07\x64\x61taset\x18\x0b \x01(\x0b\x32\x37.oak9.tython.gcp.bigquery.BigqueryDatasetAccessXDataset\x12J\n\x08timeouts\x18\x0c \x01(\x0b\x32\x38.oak9.tython.gcp.bigquery.BigqueryDatasetAccessXTimeouts\x12\x42\n\x04view\x18\r \x01(\x0b\x32\x34.oak9.tython.gcp.bigquery.BigqueryDatasetAccessXView\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"]\n#BigqueryDatasetIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x84\x02\n\x19\x42igqueryDatasetIamBinding\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12P\n\tcondition\x18\x07 \x01(\x0b\x32=.oak9.tython.gcp.bigquery.BigqueryDatasetIamBindingXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\\\n\"BigqueryDatasetIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x81\x02\n\x18\x42igqueryDatasetIamMember\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12O\n\tcondition\x18\x07 \x01(\x0b\x32<.oak9.tython.gcp.bigquery.BigqueryDatasetIamMemberXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa7\x01\n\x18\x42igqueryDatasetIamPolicy\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"d\n3BigqueryJobXCopyXDestinationEncryptionConfiguration\x12\x14\n\x0ckms_key_name\x18\x01 \x01(\t\x12\x17\n\x0fkms_key_version\x18\x02 \x01(\t\"]\n!BigqueryJobXCopyXDestinationTable\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x10\n\x08table_id\x18\x03 \x01(\t\"Y\n\x1d\x42igqueryJobXCopyXSourceTables\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x10\n\x08table_id\x18\x03 \x01(\t\"\xee\x02\n\x10\x42igqueryJobXCopy\x12\x1a\n\x12\x63reate_disposition\x18\x01 \x01(\t\x12\x19\n\x11write_disposition\x18\x02 \x01(\t\x12{\n$destination_encryption_configuration\x18\x03 \x01(\x0b\x32M.oak9.tython.gcp.bigquery.BigqueryJobXCopyXDestinationEncryptionConfiguration\x12V\n\x11\x64\x65stination_table\x18\x04 \x01(\x0b\x32;.oak9.tython.gcp.bigquery.BigqueryJobXCopyXDestinationTable\x12N\n\rsource_tables\x18\x05 \x03(\x0b\x32\x37.oak9.tython.gcp.bigquery.BigqueryJobXCopyXSourceTables\"[\n\x1f\x42igqueryJobXExtractXSourceModel\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x12\n\nproject_id\x18\x03 \x01(\t\"[\n\x1f\x42igqueryJobXExtractXSourceTable\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x10\n\x08table_id\x18\x03 \x01(\t\"\xd1\x02\n\x13\x42igqueryJobXExtract\x12\x13\n\x0b\x63ompression\x18\x01 \x01(\t\x12\x1a\n\x12\x64\x65stination_format\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65stination_uris\x18\x03 \x03(\t\x12\x17\n\x0f\x66ield_delimiter\x18\x04 \x01(\t\x12\x14\n\x0cprint_header\x18\x05 \x01(\x08\x12\x1e\n\x16use_avro_logical_types\x18\x06 \x01(\x08\x12O\n\x0csource_model\x18\x07 \x01(\x0b\x32\x39.oak9.tython.gcp.bigquery.BigqueryJobXExtractXSourceModel\x12O\n\x0csource_table\x18\x08 \x01(\x0b\x32\x39.oak9.tython.gcp.bigquery.BigqueryJobXExtractXSourceTable\"d\n3BigqueryJobXLoadXDestinationEncryptionConfiguration\x12\x14\n\x0ckms_key_name\x18\x01 \x01(\t\x12\x17\n\x0fkms_key_version\x18\x02 \x01(\t\"]\n!BigqueryJobXLoadXDestinationTable\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x10\n\x08table_id\x18\x03 \x01(\t\"W\n!BigqueryJobXLoadXTimePartitioning\x12\x15\n\rexpiration_ms\x18\x01 \x01(\t\x12\r\n\x05\x66ield\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\"\xcc\x05\n\x10\x42igqueryJobXLoad\x12\x19\n\x11\x61llow_jagged_rows\x18\x01 \x01(\x08\x12\x1d\n\x15\x61llow_quoted_newlines\x18\x02 \x01(\x08\x12\x12\n\nautodetect\x18\x03 \x01(\x08\x12\x1a\n\x12\x63reate_disposition\x18\x04 \x01(\t\x12\x10\n\x08\x65ncoding\x18\x05 \x01(\t\x12\x17\n\x0f\x66ield_delimiter\x18\x06 \x01(\t\x12\x1d\n\x15ignore_unknown_values\x18\x07 \x01(\x08\x12\x17\n\x0fmax_bad_records\x18\x08 \x01(\x01\x12\x13\n\x0bnull_marker\x18\t \x01(\t\x12\x19\n\x11projection_fields\x18\n \x03(\t\x12\r\n\x05quote\x18\x0b \x01(\t\x12\x1d\n\x15schema_update_options\x18\x0c \x03(\t\x12\x19\n\x11skip_leading_rows\x18\r \x01(\x01\x12\x15\n\rsource_format\x18\x0e \x01(\t\x12\x13\n\x0bsource_uris\x18\x0f \x03(\t\x12\x19\n\x11write_disposition\x18\x10 \x01(\t\x12{\n$destination_encryption_configuration\x18\x11 \x01(\x0b\x32M.oak9.tython.gcp.bigquery.BigqueryJobXLoadXDestinationEncryptionConfiguration\x12V\n\x11\x64\x65stination_table\x18\x12 \x01(\x0b\x32;.oak9.tython.gcp.bigquery.BigqueryJobXLoadXDestinationTable\x12V\n\x11time_partitioning\x18\x13 \x01(\x0b\x32;.oak9.tython.gcp.bigquery.BigqueryJobXLoadXTimePartitioning\"J\n BigqueryJobXQueryXDefaultDataset\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\"e\n4BigqueryJobXQueryXDestinationEncryptionConfiguration\x12\x14\n\x0ckms_key_name\x18\x01 \x01(\t\x12\x17\n\x0fkms_key_version\x18\x02 \x01(\t\"^\n\"BigqueryJobXQueryXDestinationTable\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x10\n\x08table_id\x18\x03 \x01(\t\"|\n\x1f\x42igqueryJobXQueryXScriptOptions\x12\x1c\n\x14key_result_statement\x18\x01 \x01(\t\x12\x1d\n\x15statement_byte_budget\x18\x02 \x01(\t\x12\x1c\n\x14statement_timeout_ms\x18\x03 \x01(\t\"[\n.BigqueryJobXQueryXUserDefinedFunctionResources\x12\x13\n\x0binline_code\x18\x01 \x01(\t\x12\x14\n\x0cresource_uri\x18\x02 \x01(\t\"\xb7\x06\n\x11\x42igqueryJobXQuery\x12\x1b\n\x13\x61llow_large_results\x18\x01 \x01(\x08\x12\x1a\n\x12\x63reate_disposition\x18\x02 \x01(\t\x12\x17\n\x0f\x66latten_results\x18\x03 \x01(\x08\x12\x1c\n\x14maximum_billing_tier\x18\x04 \x01(\x01\x12\x1c\n\x14maximum_bytes_billed\x18\x05 \x01(\t\x12\x16\n\x0eparameter_mode\x18\x06 \x01(\t\x12\x10\n\x08priority\x18\x07 \x01(\t\x12\r\n\x05query\x18\x08 \x01(\t\x12\x1d\n\x15schema_update_options\x18\t \x03(\t\x12\x16\n\x0euse_legacy_sql\x18\n \x01(\x08\x12\x17\n\x0fuse_query_cache\x18\x0b \x01(\x08\x12\x19\n\x11write_disposition\x18\x0c \x01(\t\x12S\n\x0f\x64\x65\x66\x61ult_dataset\x18\r \x01(\x0b\x32:.oak9.tython.gcp.bigquery.BigqueryJobXQueryXDefaultDataset\x12|\n$destination_encryption_configuration\x18\x0e \x01(\x0b\x32N.oak9.tython.gcp.bigquery.BigqueryJobXQueryXDestinationEncryptionConfiguration\x12W\n\x11\x64\x65stination_table\x18\x0f \x01(\x0b\x32<.oak9.tython.gcp.bigquery.BigqueryJobXQueryXDestinationTable\x12Q\n\x0escript_options\x18\x10 \x01(\x0b\x32\x39.oak9.tython.gcp.bigquery.BigqueryJobXQueryXScriptOptions\x12q\n\x1fuser_defined_function_resources\x18\x11 \x03(\x0b\x32H.oak9.tython.gcp.bigquery.BigqueryJobXQueryXUserDefinedFunctionResources\"6\n\x14\x42igqueryJobXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xd9\x05\n\x0b\x42igqueryJob\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\t\x12\x16\n\x0ejob_timeout_ms\x18\x03 \x01(\t\x12\x10\n\x08job_type\x18\x04 \x01(\t\x12\x41\n\x06labels\x18\x05 \x03(\x0b\x32\x31.oak9.tython.gcp.bigquery.BigqueryJob.LabelsEntry\x12\x10\n\x08location\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x41\n\x06status\x18\x08 \x03(\x0b\x32\x31.oak9.tython.gcp.bigquery.BigqueryJob.StatusEntry\x12\x12\n\nuser_email\x18\t \x01(\t\x12\x38\n\x04\x63opy\x18\n \x01(\x0b\x32*.oak9.tython.gcp.bigquery.BigqueryJobXCopy\x12>\n\x07\x65xtract\x18\x0b \x01(\x0b\x32-.oak9.tython.gcp.bigquery.BigqueryJobXExtract\x12\x38\n\x04load\x18\x0c \x01(\x0b\x32*.oak9.tython.gcp.bigquery.BigqueryJobXLoad\x12:\n\x05query\x18\r \x01(\x0b\x32+.oak9.tython.gcp.bigquery.BigqueryJobXQuery\x12@\n\x08timeouts\x18\x0e \x01(\x0b\x32..oak9.tython.gcp.bigquery.BigqueryJobXTimeouts\x12\x37\n\rresource_info\x18\x0f \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bStatusEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"N\n\x1c\x42igqueryReservationXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x87\x02\n\x13\x42igqueryReservation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x19\n\x11ignore_idle_slots\x18\x02 \x01(\x08\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x15\n\rslot_capacity\x18\x06 \x01(\x01\x12H\n\x08timeouts\x18\x07 \x01(\x0b\x32\x36.oak9.tython.gcp.bigquery.BigqueryReservationXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"H\n&BigqueryReservationAssignmentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xb1\x02\n\x1d\x42igqueryReservationAssignment\x12\x10\n\x08\x61ssignee\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08job_type\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x13\n\x0breservation\x18\x07 \x01(\t\x12\r\n\x05state\x18\x08 \x01(\t\x12R\n\x08timeouts\x18\t \x01(\x0b\x32@.oak9.tython.gcp.bigquery.BigqueryReservationAssignmentXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"a\n\x19\x42igqueryRoutineXArguments\x12\x15\n\rargument_kind\x18\x01 \x01(\t\x12\x11\n\tdata_type\x18\x02 \x01(\t\x12\x0c\n\x04mode\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"J\n\x18\x42igqueryRoutineXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x8d\x04\n\x0f\x42igqueryRoutine\x12\x15\n\rcreation_time\x18\x01 \x01(\x01\x12\x12\n\ndataset_id\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x65\x66inition_body\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x19\n\x11\x64\x65terminism_level\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x1a\n\x12imported_libraries\x18\x07 \x03(\t\x12\x10\n\x08language\x18\x08 \x01(\t\x12\x1a\n\x12last_modified_time\x18\t \x01(\x01\x12\x0f\n\x07project\x18\n \x01(\t\x12\x19\n\x11return_table_type\x18\x0b \x01(\t\x12\x13\n\x0breturn_type\x18\x0c \x01(\t\x12\x12\n\nroutine_id\x18\r \x01(\t\x12\x14\n\x0croutine_type\x18\x0e \x01(\t\x12\x46\n\targuments\x18\x0f \x03(\x0b\x32\x33.oak9.tython.gcp.bigquery.BigqueryRoutineXArguments\x12\x44\n\x08timeouts\x18\x10 \x01(\x0b\x32\x32.oak9.tython.gcp.bigquery.BigqueryRoutineXTimeouts\x12\x37\n\rresource_info\x18\x11 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"V\n%BigqueryTableXEncryptionConfiguration\x12\x14\n\x0ckms_key_name\x18\x01 \x01(\t\x12\x17\n\x0fkms_key_version\x18\x02 \x01(\t\"\xc3\x01\n2BigqueryTableXExternalDataConfigurationXCsvOptions\x12\x19\n\x11\x61llow_jagged_rows\x18\x01 \x01(\x08\x12\x1d\n\x15\x61llow_quoted_newlines\x18\x02 \x01(\x08\x12\x10\n\x08\x65ncoding\x18\x03 \x01(\t\x12\x17\n\x0f\x66ield_delimiter\x18\x04 \x01(\t\x12\r\n\x05quote\x18\x05 \x01(\t\x12\x19\n\x11skip_leading_rows\x18\x06 \x01(\x01\"a\n5BigqueryTableXExternalDataConfigurationXSheetsOptions\x12\r\n\x05range\x18\x01 \x01(\t\x12\x19\n\x11skip_leading_rows\x18\x02 \x01(\x01\"\x8c\x01\n?BigqueryTableXExternalDataConfigurationXHivePartitioningOptions\x12\x0c\n\x04mode\x18\x01 \x01(\t\x12 \n\x18require_partition_filter\x18\x02 \x01(\x08\x12\x19\n\x11source_uri_prefix\x18\x03 \x01(\t\"\xae\x04\n\'BigqueryTableXExternalDataConfiguration\x12\x12\n\nautodetect\x18\x01 \x01(\x08\x12\x13\n\x0b\x63ompression\x18\x02 \x01(\t\x12\x15\n\rconnection_id\x18\x03 \x01(\t\x12\x1d\n\x15ignore_unknown_values\x18\x04 \x01(\x08\x12\x17\n\x0fmax_bad_records\x18\x05 \x01(\x01\x12\x0e\n\x06schema\x18\x06 \x01(\t\x12\x15\n\rsource_format\x18\x07 \x01(\t\x12\x13\n\x0bsource_uris\x18\x08 \x03(\t\x12\x61\n\x0b\x63sv_options\x18\t \x01(\x0b\x32L.oak9.tython.gcp.bigquery.BigqueryTableXExternalDataConfigurationXCsvOptions\x12n\n\x15google_sheets_options\x18\n \x01(\x0b\x32O.oak9.tython.gcp.bigquery.BigqueryTableXExternalDataConfigurationXSheetsOptions\x12|\n\x19hive_partitioning_options\x18\x0b \x01(\x0b\x32Y.oak9.tython.gcp.bigquery.BigqueryTableXExternalDataConfigurationXHivePartitioningOptions\"d\n\x1e\x42igqueryTableXMaterializedView\x12\x16\n\x0e\x65nable_refresh\x18\x01 \x01(\x08\x12\r\n\x05query\x18\x02 \x01(\t\x12\x1b\n\x13refresh_interval_ms\x18\x03 \x01(\x01\"U\n%BigqueryTableXRangePartitioningXRange\x12\x0b\n\x03\x65nd\x18\x01 \x01(\x01\x12\x10\n\x08interval\x18\x02 \x01(\x01\x12\r\n\x05start\x18\x03 \x01(\x01\"\x80\x01\n\x1f\x42igqueryTableXRangePartitioning\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12N\n\x05range\x18\x02 \x01(\x0b\x32?.oak9.tython.gcp.bigquery.BigqueryTableXRangePartitioningXRange\"v\n\x1e\x42igqueryTableXTimePartitioning\x12\x15\n\rexpiration_ms\x18\x01 \x01(\x01\x12\r\n\x05\x66ield\x18\x02 \x01(\t\x12 \n\x18require_partition_filter\x18\x03 \x01(\x08\x12\x0c\n\x04type\x18\x04 \x01(\t\";\n\x12\x42igqueryTableXView\x12\r\n\x05query\x18\x01 \x01(\t\x12\x16\n\x0euse_legacy_sql\x18\x02 \x01(\x08\"\xc3\x08\n\rBigqueryTable\x12\x12\n\nclustering\x18\x01 \x03(\t\x12\x15\n\rcreation_time\x18\x02 \x01(\x01\x12\x12\n\ndataset_id\x18\x03 \x01(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x04 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x0c\n\x04\x65tag\x18\x06 \x01(\t\x12\x17\n\x0f\x65xpiration_time\x18\x07 \x01(\x01\x12\x15\n\rfriendly_name\x18\x08 \x01(\t\x12\n\n\x02id\x18\t \x01(\t\x12\x43\n\x06labels\x18\n \x03(\x0b\x32\x33.oak9.tython.gcp.bigquery.BigqueryTable.LabelsEntry\x12\x1a\n\x12last_modified_time\x18\x0b \x01(\x01\x12\x10\n\x08location\x18\x0c \x01(\t\x12\x11\n\tnum_bytes\x18\r \x01(\x01\x12\x1b\n\x13num_long_term_bytes\x18\x0e \x01(\x01\x12\x10\n\x08num_rows\x18\x0f \x01(\x01\x12\x0f\n\x07project\x18\x10 \x01(\t\x12\x0e\n\x06schema\x18\x11 \x01(\t\x12\x11\n\tself_link\x18\x12 \x01(\t\x12\x10\n\x08table_id\x18\x13 \x01(\t\x12\x0c\n\x04type\x18\x14 \x01(\t\x12\x61\n\x18\x65ncryption_configuration\x18\x15 \x01(\x0b\x32?.oak9.tython.gcp.bigquery.BigqueryTableXEncryptionConfiguration\x12\x66\n\x1b\x65xternal_data_configuration\x18\x16 \x01(\x0b\x32\x41.oak9.tython.gcp.bigquery.BigqueryTableXExternalDataConfiguration\x12S\n\x11materialized_view\x18\x17 \x01(\x0b\x32\x38.oak9.tython.gcp.bigquery.BigqueryTableXMaterializedView\x12U\n\x12range_partitioning\x18\x18 \x01(\x0b\x32\x39.oak9.tython.gcp.bigquery.BigqueryTableXRangePartitioning\x12S\n\x11time_partitioning\x18\x19 \x01(\x0b\x32\x38.oak9.tython.gcp.bigquery.BigqueryTableXTimePartitioning\x12:\n\x04view\x18\x1a \x01(\x0b\x32,.oak9.tython.gcp.bigquery.BigqueryTableXView\x12\x37\n\rresource_info\x18\x1b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"[\n!BigqueryTableIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x92\x02\n\x17\x42igqueryTableIamBinding\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x10\n\x08table_id\x18\x07 \x01(\t\x12N\n\tcondition\x18\x08 \x01(\x0b\x32;.oak9.tython.gcp.bigquery.BigqueryTableIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Z\n BigqueryTableIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x8f\x02\n\x16\x42igqueryTableIamMember\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x10\n\x08table_id\x18\x07 \x01(\t\x12M\n\tcondition\x18\x08 \x01(\x0b\x32:.oak9.tython.gcp.bigquery.BigqueryTableIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb7\x01\n\x16\x42igqueryTableIamPolicy\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x10\n\x08table_id\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_bigquery_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BIGQUERYDATATRANSFERCONFIG_PARAMSENTRY._options = None
  _BIGQUERYDATATRANSFERCONFIG_PARAMSENTRY._serialized_options = b'8\001'
  _BIGQUERYDATASET_LABELSENTRY._options = None
  _BIGQUERYDATASET_LABELSENTRY._serialized_options = b'8\001'
  _BIGQUERYJOB_LABELSENTRY._options = None
  _BIGQUERYJOB_LABELSENTRY._serialized_options = b'8\001'
  _BIGQUERYJOB_STATUSENTRY._options = None
  _BIGQUERYJOB_STATUSENTRY._serialized_options = b'8\001'
  _BIGQUERYTABLE_LABELSENTRY._options = None
  _BIGQUERYTABLE_LABELSENTRY._serialized_options = b'8\001'
  _BIGQUERYCONNECTIONXAWSXACCESSROLE._serialized_start=73
  _BIGQUERYCONNECTIONXAWSXACCESSROLE._serialized_end=147
  _BIGQUERYCONNECTIONXAWS._serialized_start=149
  _BIGQUERYCONNECTIONXAWS._serialized_end=255
  _BIGQUERYCONNECTIONXAZURE._serialized_start=258
  _BIGQUERYCONNECTIONXAZURE._serialized_end=393
  _BIGQUERYCONNECTIONXCLOUDRESOURCE._serialized_start=395
  _BIGQUERYCONNECTIONXCLOUDRESOURCE._serialized_end=457
  _BIGQUERYCONNECTIONXCLOUDSPANNER._serialized_start=459
  _BIGQUERYCONNECTIONXCLOUDSPANNER._serialized_end=535
  _BIGQUERYCONNECTIONXCLOUDSQLXCREDENTIAL._serialized_start=537
  _BIGQUERYCONNECTIONXCLOUDSQLXCREDENTIAL._serialized_end=613
  _BIGQUERYCONNECTIONXCLOUDSQL._serialized_start=616
  _BIGQUERYCONNECTIONXCLOUDSQL._serialized_end=784
  _BIGQUERYCONNECTIONXTIMEOUTS._serialized_start=786
  _BIGQUERYCONNECTIONXTIMEOUTS._serialized_end=863
  _BIGQUERYCONNECTION._serialized_start=866
  _BIGQUERYCONNECTION._serialized_end=1538
  _BIGQUERYCONNECTIONIAMBINDINGXCONDITION._serialized_start=1540
  _BIGQUERYCONNECTIONIAMBINDINGXCONDITION._serialized_end=1636
  _BIGQUERYCONNECTIONIAMBINDING._serialized_start=1639
  _BIGQUERYCONNECTIONIAMBINDING._serialized_end=1926
  _BIGQUERYCONNECTIONIAMMEMBERXCONDITION._serialized_start=1928
  _BIGQUERYCONNECTIONIAMMEMBERXCONDITION._serialized_end=2023
  _BIGQUERYCONNECTIONIAMMEMBER._serialized_start=2026
  _BIGQUERYCONNECTIONIAMMEMBER._serialized_end=2310
  _BIGQUERYCONNECTIONIAMPOLICY._serialized_start=2313
  _BIGQUERYCONNECTIONIAMPOLICY._serialized_end=2504
  _BIGQUERYDATATRANSFERCONFIGXEMAILPREFERENCES._serialized_start=2506
  _BIGQUERYDATATRANSFERCONFIGXEMAILPREFERENCES._serialized_end=2581
  _BIGQUERYDATATRANSFERCONFIGXSCHEDULEOPTIONS._serialized_start=2583
  _BIGQUERYDATATRANSFERCONFIGXSCHEDULEOPTIONS._serialized_end=2698
  _BIGQUERYDATATRANSFERCONFIGXSENSITIVEPARAMS._serialized_start=2700
  _BIGQUERYDATATRANSFERCONFIGXSENSITIVEPARAMS._serialized_end=2771
  _BIGQUERYDATATRANSFERCONFIGXTIMEOUTS._serialized_start=2773
  _BIGQUERYDATATRANSFERCONFIGXTIMEOUTS._serialized_end=2858
  _BIGQUERYDATATRANSFERCONFIG._serialized_start=2861
  _BIGQUERYDATATRANSFERCONFIG._serialized_end=3720
  _BIGQUERYDATATRANSFERCONFIG_PARAMSENTRY._serialized_start=3675
  _BIGQUERYDATATRANSFERCONFIG_PARAMSENTRY._serialized_end=3720
  _BIGQUERYDATASETXACCESSXDATASETXDATASET._serialized_start=3722
  _BIGQUERYDATASETXACCESSXDATASETXDATASET._serialized_end=3802
  _BIGQUERYDATASETXACCESSXDATASET._serialized_start=3805
  _BIGQUERYDATASETXACCESSXDATASET._serialized_end=3942
  _BIGQUERYDATASETXACCESSXVIEW._serialized_start=3944
  _BIGQUERYDATASETXACCESSXVIEW._serialized_end=4031
  _BIGQUERYDATASETXACCESS._serialized_start=4034
  _BIGQUERYDATASETXACCESS._serialized_end=4302
  _BIGQUERYDATASETXDEFAULTENCRYPTIONCONFIGURATION._serialized_start=4304
  _BIGQUERYDATASETXDEFAULTENCRYPTIONCONFIGURATION._serialized_end=4374
  _BIGQUERYDATASETXTIMEOUTS._serialized_start=4376
  _BIGQUERYDATASETXTIMEOUTS._serialized_end=4450
  _BIGQUERYDATASET._serialized_start=4453
  _BIGQUERYDATASET._serialized_end=5206
  _BIGQUERYDATASET_LABELSENTRY._serialized_start=5161
  _BIGQUERYDATASET_LABELSENTRY._serialized_end=5206
  _BIGQUERYDATASETACCESSXDATASETXDATASET._serialized_start=5208
  _BIGQUERYDATASETACCESSXDATASETXDATASET._serialized_end=5287
  _BIGQUERYDATASETACCESSXDATASET._serialized_start=5290
  _BIGQUERYDATASETACCESSXDATASET._serialized_end=5425
  _BIGQUERYDATASETACCESSXTIMEOUTS._serialized_start=5427
  _BIGQUERYDATASETACCESSXTIMEOUTS._serialized_end=5491
  _BIGQUERYDATASETACCESSXVIEW._serialized_start=5493
  _BIGQUERYDATASETACCESSXVIEW._serialized_end=5579
  _BIGQUERYDATASETACCESS._serialized_start=5582
  _BIGQUERYDATASETACCESS._serialized_end=6077
  _BIGQUERYDATASETIAMBINDINGXCONDITION._serialized_start=6079
  _BIGQUERYDATASETIAMBINDINGXCONDITION._serialized_end=6172
  _BIGQUERYDATASETIAMBINDING._serialized_start=6175
  _BIGQUERYDATASETIAMBINDING._serialized_end=6435
  _BIGQUERYDATASETIAMMEMBERXCONDITION._serialized_start=6437
  _BIGQUERYDATASETIAMMEMBERXCONDITION._serialized_end=6529
  _BIGQUERYDATASETIAMMEMBER._serialized_start=6532
  _BIGQUERYDATASETIAMMEMBER._serialized_end=6789
  _BIGQUERYDATASETIAMPOLICY._serialized_start=6792
  _BIGQUERYDATASETIAMPOLICY._serialized_end=6959
  _BIGQUERYJOBXCOPYXDESTINATIONENCRYPTIONCONFIGURATION._serialized_start=6961
  _BIGQUERYJOBXCOPYXDESTINATIONENCRYPTIONCONFIGURATION._serialized_end=7061
  _BIGQUERYJOBXCOPYXDESTINATIONTABLE._serialized_start=7063
  _BIGQUERYJOBXCOPYXDESTINATIONTABLE._serialized_end=7156
  _BIGQUERYJOBXCOPYXSOURCETABLES._serialized_start=7158
  _BIGQUERYJOBXCOPYXSOURCETABLES._serialized_end=7247
  _BIGQUERYJOBXCOPY._serialized_start=7250
  _BIGQUERYJOBXCOPY._serialized_end=7616
  _BIGQUERYJOBXEXTRACTXSOURCEMODEL._serialized_start=7618
  _BIGQUERYJOBXEXTRACTXSOURCEMODEL._serialized_end=7709
  _BIGQUERYJOBXEXTRACTXSOURCETABLE._serialized_start=7711
  _BIGQUERYJOBXEXTRACTXSOURCETABLE._serialized_end=7802
  _BIGQUERYJOBXEXTRACT._serialized_start=7805
  _BIGQUERYJOBXEXTRACT._serialized_end=8142
  _BIGQUERYJOBXLOADXDESTINATIONENCRYPTIONCONFIGURATION._serialized_start=8144
  _BIGQUERYJOBXLOADXDESTINATIONENCRYPTIONCONFIGURATION._serialized_end=8244
  _BIGQUERYJOBXLOADXDESTINATIONTABLE._serialized_start=8246
  _BIGQUERYJOBXLOADXDESTINATIONTABLE._serialized_end=8339
  _BIGQUERYJOBXLOADXTIMEPARTITIONING._serialized_start=8341
  _BIGQUERYJOBXLOADXTIMEPARTITIONING._serialized_end=8428
  _BIGQUERYJOBXLOAD._serialized_start=8431
  _BIGQUERYJOBXLOAD._serialized_end=9147
  _BIGQUERYJOBXQUERYXDEFAULTDATASET._serialized_start=9149
  _BIGQUERYJOBXQUERYXDEFAULTDATASET._serialized_end=9223
  _BIGQUERYJOBXQUERYXDESTINATIONENCRYPTIONCONFIGURATION._serialized_start=9225
  _BIGQUERYJOBXQUERYXDESTINATIONENCRYPTIONCONFIGURATION._serialized_end=9326
  _BIGQUERYJOBXQUERYXDESTINATIONTABLE._serialized_start=9328
  _BIGQUERYJOBXQUERYXDESTINATIONTABLE._serialized_end=9422
  _BIGQUERYJOBXQUERYXSCRIPTOPTIONS._serialized_start=9424
  _BIGQUERYJOBXQUERYXSCRIPTOPTIONS._serialized_end=9548
  _BIGQUERYJOBXQUERYXUSERDEFINEDFUNCTIONRESOURCES._serialized_start=9550
  _BIGQUERYJOBXQUERYXUSERDEFINEDFUNCTIONRESOURCES._serialized_end=9641
  _BIGQUERYJOBXQUERY._serialized_start=9644
  _BIGQUERYJOBXQUERY._serialized_end=10467
  _BIGQUERYJOBXTIMEOUTS._serialized_start=10469
  _BIGQUERYJOBXTIMEOUTS._serialized_end=10523
  _BIGQUERYJOB._serialized_start=10526
  _BIGQUERYJOB._serialized_end=11255
  _BIGQUERYJOB_LABELSENTRY._serialized_start=5161
  _BIGQUERYJOB_LABELSENTRY._serialized_end=5206
  _BIGQUERYJOB_STATUSENTRY._serialized_start=11210
  _BIGQUERYJOB_STATUSENTRY._serialized_end=11255
  _BIGQUERYRESERVATIONXTIMEOUTS._serialized_start=11257
  _BIGQUERYRESERVATIONXTIMEOUTS._serialized_end=11335
  _BIGQUERYRESERVATION._serialized_start=11338
  _BIGQUERYRESERVATION._serialized_end=11601
  _BIGQUERYRESERVATIONASSIGNMENTXTIMEOUTS._serialized_start=11603
  _BIGQUERYRESERVATIONASSIGNMENTXTIMEOUTS._serialized_end=11675
  _BIGQUERYRESERVATIONASSIGNMENT._serialized_start=11678
  _BIGQUERYRESERVATIONASSIGNMENT._serialized_end=11983
  _BIGQUERYROUTINEXARGUMENTS._serialized_start=11985
  _BIGQUERYROUTINEXARGUMENTS._serialized_end=12082
  _BIGQUERYROUTINEXTIMEOUTS._serialized_start=12084
  _BIGQUERYROUTINEXTIMEOUTS._serialized_end=12158
  _BIGQUERYROUTINE._serialized_start=12161
  _BIGQUERYROUTINE._serialized_end=12686
  _BIGQUERYTABLEXENCRYPTIONCONFIGURATION._serialized_start=12688
  _BIGQUERYTABLEXENCRYPTIONCONFIGURATION._serialized_end=12774
  _BIGQUERYTABLEXEXTERNALDATACONFIGURATIONXCSVOPTIONS._serialized_start=12777
  _BIGQUERYTABLEXEXTERNALDATACONFIGURATIONXCSVOPTIONS._serialized_end=12972
  _BIGQUERYTABLEXEXTERNALDATACONFIGURATIONXSHEETSOPTIONS._serialized_start=12974
  _BIGQUERYTABLEXEXTERNALDATACONFIGURATIONXSHEETSOPTIONS._serialized_end=13071
  _BIGQUERYTABLEXEXTERNALDATACONFIGURATIONXHIVEPARTITIONINGOPTIONS._serialized_start=13074
  _BIGQUERYTABLEXEXTERNALDATACONFIGURATIONXHIVEPARTITIONINGOPTIONS._serialized_end=13214
  _BIGQUERYTABLEXEXTERNALDATACONFIGURATION._serialized_start=13217
  _BIGQUERYTABLEXEXTERNALDATACONFIGURATION._serialized_end=13775
  _BIGQUERYTABLEXMATERIALIZEDVIEW._serialized_start=13777
  _BIGQUERYTABLEXMATERIALIZEDVIEW._serialized_end=13877
  _BIGQUERYTABLEXRANGEPARTITIONINGXRANGE._serialized_start=13879
  _BIGQUERYTABLEXRANGEPARTITIONINGXRANGE._serialized_end=13964
  _BIGQUERYTABLEXRANGEPARTITIONING._serialized_start=13967
  _BIGQUERYTABLEXRANGEPARTITIONING._serialized_end=14095
  _BIGQUERYTABLEXTIMEPARTITIONING._serialized_start=14097
  _BIGQUERYTABLEXTIMEPARTITIONING._serialized_end=14215
  _BIGQUERYTABLEXVIEW._serialized_start=14217
  _BIGQUERYTABLEXVIEW._serialized_end=14276
  _BIGQUERYTABLE._serialized_start=14279
  _BIGQUERYTABLE._serialized_end=15370
  _BIGQUERYTABLE_LABELSENTRY._serialized_start=5161
  _BIGQUERYTABLE_LABELSENTRY._serialized_end=5206
  _BIGQUERYTABLEIAMBINDINGXCONDITION._serialized_start=15372
  _BIGQUERYTABLEIAMBINDINGXCONDITION._serialized_end=15463
  _BIGQUERYTABLEIAMBINDING._serialized_start=15466
  _BIGQUERYTABLEIAMBINDING._serialized_end=15740
  _BIGQUERYTABLEIAMMEMBERXCONDITION._serialized_start=15742
  _BIGQUERYTABLEIAMMEMBERXCONDITION._serialized_end=15832
  _BIGQUERYTABLEIAMMEMBER._serialized_start=15835
  _BIGQUERYTABLEIAMMEMBER._serialized_end=16106
  _BIGQUERYTABLEIAMPOLICY._serialized_start=16109
  _BIGQUERYTABLEIAMPOLICY._serialized_end=16292
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.flowcontrol.v1beta2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:kubernetes/kubernetes_io.k8s.api.flowcontrol.v1beta2.proto\x12\'oak9.tython.k8s.api.flowcontrol.v1beta2\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\"`\n\x17\x46lowDistinguisherMethod\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc7\x02\n\nFlowSchema\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x45\n\x04spec\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.api.flowcontrol.v1beta2.FlowSchemaSpec\x12I\n\x06status\x18\x05 \x01(\x0b\x32\x39.oak9.tython.k8s.api.flowcontrol.v1beta2.FlowSchemaStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe0\x01\n\x13\x46lowSchemaCondition\x12Q\n\x14last_transition_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xfb\x01\n\x0e\x46lowSchemaList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x42\n\x05items\x18\x02 \x03(\x0b\x32\x33.oak9.tython.k8s.api.flowcontrol.v1beta2.FlowSchema\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8b\x03\n\x0e\x46lowSchemaSpec\x12^\n\x14\x64istinguisher_method\x18\x01 \x01(\x0b\x32@.oak9.tython.k8s.api.flowcontrol.v1beta2.FlowDistinguisherMethod\x12\x1b\n\x13matching_precedence\x18\x02 \x01(\x05\x12r\n\x1cpriority_level_configuration\x18\x03 \x01(\x0b\x32L.oak9.tython.k8s.api.flowcontrol.v1beta2.PriorityLevelConfigurationReference\x12O\n\x05rules\x18\x04 \x03(\x0b\x32@.oak9.tython.k8s.api.flowcontrol.v1beta2.PolicyRulesWithSubjects\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9d\x01\n\x10\x46lowSchemaStatus\x12P\n\nconditions\x18\x01 \x03(\x0b\x32<.oak9.tython.k8s.api.flowcontrol.v1beta2.FlowSchemaCondition\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"U\n\x0cGroupSubject\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa6\x01\n\rLimitResponse\x12N\n\x07queuing\x18\x01 \x01(\x0b\x32=.oak9.tython.k8s.api.flowcontrol.v1beta2.QueuingConfiguration\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8b\x02\n!LimitedPriorityLevelConfiguration\x12\"\n\x1a\x61ssured_concurrency_shares\x18\x01 \x01(\x05\x12\x1f\n\x17\x62orrowing_limit_percent\x18\x02 \x01(\x05\x12\x18\n\x10lendable_percent\x18\x03 \x01(\x05\x12N\n\x0elimit_response\x18\x04 \x01(\x0b\x32\x36.oak9.tython.k8s.api.flowcontrol.v1beta2.LimitResponse\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"|\n\x15NonResourcePolicyRule\x12\x1b\n\x13non_resource_u_r_ls\x18\x01 \x03(\t\x12\r\n\x05verbs\x18\x02 \x03(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc7\x02\n\x17PolicyRulesWithSubjects\x12Z\n\x12non_resource_rules\x18\x01 \x03(\x0b\x32>.oak9.tython.k8s.api.flowcontrol.v1beta2.NonResourcePolicyRule\x12S\n\x0eresource_rules\x18\x02 \x03(\x0b\x32;.oak9.tython.k8s.api.flowcontrol.v1beta2.ResourcePolicyRule\x12\x42\n\x08subjects\x18\x03 \x03(\x0b\x32\x30.oak9.tython.k8s.api.flowcontrol.v1beta2.Subject\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf7\x02\n\x1aPriorityLevelConfiguration\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12U\n\x04spec\x18\x04 \x01(\x0b\x32G.oak9.tython.k8s.api.flowcontrol.v1beta2.PriorityLevelConfigurationSpec\x12Y\n\x06status\x18\x05 \x01(\x0b\x32I.oak9.tython.k8s.api.flowcontrol.v1beta2.PriorityLevelConfigurationStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf0\x01\n#PriorityLevelConfigurationCondition\x12Q\n\x14last_transition_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9b\x02\n\x1ePriorityLevelConfigurationList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12R\n\x05items\x18\x02 \x03(\x0b\x32\x43.oak9.tython.k8s.api.flowcontrol.v1beta2.PriorityLevelConfiguration\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"l\n#PriorityLevelConfigurationReference\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc4\x01\n\x1ePriorityLevelConfigurationSpec\x12[\n\x07limited\x18\x01 \x01(\x0b\x32J.oak9.tython.k8s.api.flowcontrol.v1beta2.LimitedPriorityLevelConfiguration\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbd\x01\n PriorityLevelConfigurationStatus\x12`\n\nconditions\x18\x01 \x03(\x0b\x32L.oak9.tython.k8s.api.flowcontrol.v1beta2.PriorityLevelConfigurationCondition\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8e\x01\n\x14QueuingConfiguration\x12\x11\n\thand_size\x18\x01 \x01(\x05\x12\x1a\n\x12queue_length_limit\x18\x02 \x01(\x05\x12\x0e\n\x06queues\x18\x03 \x01(\x05\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xae\x01\n\x12ResourcePolicyRule\x12\x12\n\napi_groups\x18\x01 \x03(\t\x12\x15\n\rcluster_scope\x18\x02 \x01(\x08\x12\x12\n\nnamespaces\x18\x03 \x03(\t\x12\x11\n\tresources\x18\x04 \x03(\t\x12\r\n\x05verbs\x18\x05 \x03(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"q\n\x15ServiceAccountSubject\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb3\x02\n\x07Subject\x12\x44\n\x05group\x18\x01 \x01(\x0b\x32\x35.oak9.tython.k8s.api.flowcontrol.v1beta2.GroupSubject\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12W\n\x0fservice_account\x18\x03 \x01(\x0b\x32>.oak9.tython.k8s.api.flowcontrol.v1beta2.ServiceAccountSubject\x12\x42\n\x04user\x18\x04 \x01(\x0b\x32\x34.oak9.tython.k8s.api.flowcontrol.v1beta2.UserSubject\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"T\n\x0bUserSubject\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.flowcontrol.v1beta2_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FLOWDISTINGUISHERMETHOD._serialized_start=190
  _FLOWDISTINGUISHERMETHOD._serialized_end=286
  _FLOWSCHEMA._serialized_start=289
  _FLOWSCHEMA._serialized_end=616
  _FLOWSCHEMACONDITION._serialized_start=619
  _FLOWSCHEMACONDITION._serialized_end=843
  _FLOWSCHEMALIST._serialized_start=846
  _FLOWSCHEMALIST._serialized_end=1097
  _FLOWSCHEMASPEC._serialized_start=1100
  _FLOWSCHEMASPEC._serialized_end=1495
  _FLOWSCHEMASTATUS._serialized_start=1498
  _FLOWSCHEMASTATUS._serialized_end=1655
  _GROUPSUBJECT._serialized_start=1657
  _GROUPSUBJECT._serialized_end=1742
  _LIMITRESPONSE._serialized_start=1745
  _LIMITRESPONSE._serialized_end=1911
  _LIMITEDPRIORITYLEVELCONFIGURATION._serialized_start=1914
  _LIMITEDPRIORITYLEVELCONFIGURATION._serialized_end=2181
  _NONRESOURCEPOLICYRULE._serialized_start=2183
  _NONRESOURCEPOLICYRULE._serialized_end=2307
  _POLICYRULESWITHSUBJECTS._serialized_start=2310
  _POLICYRULESWITHSUBJECTS._serialized_end=2637
  _PRIORITYLEVELCONFIGURATION._serialized_start=2640
  _PRIORITYLEVELCONFIGURATION._serialized_end=3015
  _PRIORITYLEVELCONFIGURATIONCONDITION._serialized_start=3018
  _PRIORITYLEVELCONFIGURATIONCONDITION._serialized_end=3258
  _PRIORITYLEVELCONFIGURATIONLIST._serialized_start=3261
  _PRIORITYLEVELCONFIGURATIONLIST._serialized_end=3544
  _PRIORITYLEVELCONFIGURATIONREFERENCE._serialized_start=3546
  _PRIORITYLEVELCONFIGURATIONREFERENCE._serialized_end=3654
  _PRIORITYLEVELCONFIGURATIONSPEC._serialized_start=3657
  _PRIORITYLEVELCONFIGURATIONSPEC._serialized_end=3853
  _PRIORITYLEVELCONFIGURATIONSTATUS._serialized_start=3856
  _PRIORITYLEVELCONFIGURATIONSTATUS._serialized_end=4045
  _QUEUINGCONFIGURATION._serialized_start=4048
  _QUEUINGCONFIGURATION._serialized_end=4190
  _RESOURCEPOLICYRULE._serialized_start=4193
  _RESOURCEPOLICYRULE._serialized_end=4367
  _SERVICEACCOUNTSUBJECT._serialized_start=4369
  _SERVICEACCOUNTSUBJECT._serialized_end=4482
  _SUBJECT._serialized_start=4485
  _SUBJECT._serialized_end=4792
  _USERSUBJECT._serialized_start=4794
  _USERSUBJECT._serialized_end=4878
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.api.apps.v1_pb2
import kubernetes.kubernetes_io.k8s.api.autoscaling.v2_pb2
import kubernetes.kubernetes_io.k8s.api.core.v1_pb2
import kubernetes.kubernetes_io.k8s.api.networking.v1_pb2
import kubernetes.kubernetes_io.k8s.api.rbac.v1_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Kubernetes_Namespaced(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BINDING_FIELD_NUMBER: builtins.int
    CONFIG_MAP_FIELD_NUMBER: builtins.int
    POD_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    DAEMON_SET_FIELD_NUMBER: builtins.int
    DEPLOYMENT_FIELD_NUMBER: builtins.int
    REPLICA_SET_FIELD_NUMBER: builtins.int
    STATEFUL_SET_FIELD_NUMBER: builtins.int
    HORIZONTAL_POD_AUTOSCALER_FIELD_NUMBER: builtins.int
    POD_TEMPLATE_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    ROLE_BINDING_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    INGRESS_FIELD_NUMBER: builtins.int
    NETWORK_POLICY_FIELD_NUMBER: builtins.int
    @property
    def binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.Binding]: ...
    @property
    def config_map(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.ConfigMap]: ...
    @property
    def pod(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.Pod]: ...
    @property
    def service_account(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.ServiceAccount]: ...
    @property
    def service(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.Service]: ...
    @property
    def daemon_set(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.apps.v1_pb2.DaemonSet]: ...
    @property
    def deployment(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.apps.v1_pb2.Deployment]: ...
    @property
    def replica_set(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.apps.v1_pb2.ReplicaSet]: ...
    @property
    def stateful_set(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.apps.v1_pb2.StatefulSet]: ...
    @property
    def horizontal_pod_autoscaler(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.autoscaling.v2_pb2.HorizontalPodAutoscaler]: ...
    @property
    def pod_template(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PodTemplate]: ...
    @property
    def secret(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.Secret]: ...
    @property
    def role_binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.rbac.v1_pb2.RoleBinding]: ...
    @property
    def role(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.rbac.v1_pb2.Role]: ...
    @property
    def ingress(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.networking.v1_pb2.Ingress]: ...
    @property
    def network_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.networking.v1_pb2.NetworkPolicy]: ...
    def __init__(
        self,
        *,
        binding: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.Binding] | None = ...,
        config_map: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.ConfigMap] | None = ...,
        pod: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.Pod] | None = ...,
        service_account: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.ServiceAccount] | None = ...,
        service: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.Service] | None = ...,
        daemon_set: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.apps.v1_pb2.DaemonSet] | None = ...,
        deployment: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.apps.v1_pb2.Deployment] | None = ...,
        replica_set: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.apps.v1_pb2.ReplicaSet] | None = ...,
        stateful_set: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.apps.v1_pb2.StatefulSet] | None = ...,
        horizontal_pod_autoscaler: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.autoscaling.v2_pb2.HorizontalPodAutoscaler] | None = ...,
        pod_template: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PodTemplate] | None = ...,
        secret: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.Secret] | None = ...,
        role_binding: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.rbac.v1_pb2.RoleBinding] | None = ...,
        role: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.rbac.v1_pb2.Role] | None = ...,
        ingress: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.networking.v1_pb2.Ingress] | None = ...,
        network_policy: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.networking.v1_pb2.NetworkPolicy] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["binding", b"binding", "config_map", b"config_map", "daemon_set", b"daemon_set", "deployment", b"deployment", "horizontal_pod_autoscaler", b"horizontal_pod_autoscaler", "ingress", b"ingress", "network_policy", b"network_policy", "pod", b"pod", "pod_template", b"pod_template", "replica_set", b"replica_set", "role", b"role", "role_binding", b"role_binding", "secret", b"secret", "service", b"service", "service_account", b"service_account", "stateful_set", b"stateful_set"]) -> None: ...

global___Kubernetes_Namespaced = Kubernetes_Namespaced



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import gcp.gcp_cloud_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleCloudTasks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_TASKS_QUEUE_FIELD_NUMBER: builtins.int
    CLOUD_TASKS_QUEUE_IAM_BINDING_FIELD_NUMBER: builtins.int
    CLOUD_TASKS_QUEUE_IAM_MEMBER_FIELD_NUMBER: builtins.int
    CLOUD_TASKS_QUEUE_IAM_POLICY_FIELD_NUMBER: builtins.int
    @property
    def cloud_tasks_queue(self) -> gcp.gcp_cloud_pb2.CloudTasksQueue: ...
    @property
    def cloud_tasks_queue_iam_binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_cloud_pb2.CloudTasksQueueIamBinding]: ...
    @property
    def cloud_tasks_queue_iam_member(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_cloud_pb2.CloudTasksQueueIamMember]: ...
    @property
    def cloud_tasks_queue_iam_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_cloud_pb2.CloudTasksQueueIamPolicy]: ...
    def __init__(
        self,
        *,
        cloud_tasks_queue: gcp.gcp_cloud_pb2.CloudTasksQueue | None = ...,
        cloud_tasks_queue_iam_binding: collections.abc.Iterable[gcp.gcp_cloud_pb2.CloudTasksQueueIamBinding] | None = ...,
        cloud_tasks_queue_iam_member: collections.abc.Iterable[gcp.gcp_cloud_pb2.CloudTasksQueueIamMember] | None = ...,
        cloud_tasks_queue_iam_policy: collections.abc.Iterable[gcp.gcp_cloud_pb2.CloudTasksQueueIamPolicy] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_tasks_queue", b"cloud_tasks_queue"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_tasks_queue", b"cloud_tasks_queue", "cloud_tasks_queue_iam_binding", b"cloud_tasks_queue_iam_binding", "cloud_tasks_queue_iam_member", b"cloud_tasks_queue_iam_member", "cloud_tasks_queue_iam_policy", b"cloud_tasks_queue_iam_policy"]) -> None: ...

global___GoogleCloudTasks = GoogleCloudTasks



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_dns.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11gcp/gcp_dns.proto\x12\x13oak9.tython.gcp.dns\x1a\x13shared/shared.proto\"t\n+DnsManagedZoneXDnssecConfigXDefaultKeySpecs\x12\x11\n\talgorithm\x18\x01 \x01(\t\x12\x12\n\nkey_length\x18\x02 \x01(\x01\x12\x10\n\x08key_type\x18\x03 \x01(\t\x12\x0c\n\x04kind\x18\x04 \x01(\t\"\xae\x01\n\x1b\x44nsManagedZoneXDnssecConfig\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12\x15\n\rnon_existence\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\t\x12[\n\x11\x64\x65\x66\x61ult_key_specs\x18\x04 \x03(\x0b\x32@.oak9.tython.gcp.dns.DnsManagedZoneXDnssecConfigXDefaultKeySpecs\"b\n1DnsManagedZoneXForwardingConfigXTargetNameServers\x12\x17\n\x0f\x66orwarding_path\x18\x01 \x01(\t\x12\x14\n\x0cipv4_address\x18\x02 \x01(\t\"\x86\x01\n\x1f\x44nsManagedZoneXForwardingConfig\x12\x63\n\x13target_name_servers\x18\x01 \x03(\x0b\x32\x46.oak9.tython.gcp.dns.DnsManagedZoneXForwardingConfigXTargetNameServers\"A\n*DnsManagedZoneXPeeringConfigXTargetNetwork\x12\x13\n\x0bnetwork_url\x18\x01 \x01(\t\"w\n\x1c\x44nsManagedZoneXPeeringConfig\x12W\n\x0etarget_network\x18\x01 \x01(\x0b\x32?.oak9.tython.gcp.dns.DnsManagedZoneXPeeringConfigXTargetNetwork\"F\n/DnsManagedZoneXPrivateVisibilityConfigXNetworks\x12\x13\n\x0bnetwork_url\x18\x01 \x01(\t\"\x80\x01\n&DnsManagedZoneXPrivateVisibilityConfig\x12V\n\x08networks\x18\x01 \x03(\x0b\x32\x44.oak9.tython.gcp.dns.DnsManagedZoneXPrivateVisibilityConfigXNetworks\"I\n\x17\x44nsManagedZoneXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x81\x06\n\x0e\x44nsManagedZone\x12\x15\n\rcreation_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08\x64ns_name\x18\x03 \x01(\t\x12\x15\n\rforce_destroy\x18\x04 \x01(\x08\x12\n\n\x02id\x18\x05 \x01(\t\x12?\n\x06labels\x18\x06 \x03(\x0b\x32/.oak9.tython.gcp.dns.DnsManagedZone.LabelsEntry\x12\x17\n\x0fmanaged_zone_id\x18\x07 \x01(\x01\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x14\n\x0cname_servers\x18\t \x03(\t\x12\x0f\n\x07project\x18\n \x01(\t\x12\x12\n\nvisibility\x18\x0b \x01(\t\x12G\n\rdnssec_config\x18\x0c \x01(\x0b\x32\x30.oak9.tython.gcp.dns.DnsManagedZoneXDnssecConfig\x12O\n\x11\x66orwarding_config\x18\r \x01(\x0b\x32\x34.oak9.tython.gcp.dns.DnsManagedZoneXForwardingConfig\x12I\n\x0epeering_config\x18\x0e \x01(\x0b\x32\x31.oak9.tython.gcp.dns.DnsManagedZoneXPeeringConfig\x12^\n\x19private_visibility_config\x18\x0f \x01(\x0b\x32;.oak9.tython.gcp.dns.DnsManagedZoneXPrivateVisibilityConfig\x12>\n\x08timeouts\x18\x10 \x01(\x0b\x32,.oak9.tython.gcp.dns.DnsManagedZoneXTimeouts\x12\x37\n\rresource_info\x18\x11 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"h\n7DnsPolicyXAlternativeNameServerConfigXTargetNameServers\x12\x17\n\x0f\x66orwarding_path\x18\x01 \x01(\t\x12\x14\n\x0cipv4_address\x18\x02 \x01(\t\"\x92\x01\n%DnsPolicyXAlternativeNameServerConfig\x12i\n\x13target_name_servers\x18\x01 \x03(\x0b\x32L.oak9.tython.gcp.dns.DnsPolicyXAlternativeNameServerConfigXTargetNameServers\")\n\x12\x44nsPolicyXNetworks\x12\x13\n\x0bnetwork_url\x18\x01 \x01(\t\"D\n\x12\x44nsPolicyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x99\x03\n\tDnsPolicy\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12!\n\x19\x65nable_inbound_forwarding\x18\x02 \x01(\x08\x12\x16\n\x0e\x65nable_logging\x18\x03 \x01(\x08\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x62\n\x1e\x61lternative_name_server_config\x18\x07 \x01(\x0b\x32:.oak9.tython.gcp.dns.DnsPolicyXAlternativeNameServerConfig\x12\x39\n\x08networks\x18\x08 \x03(\x0b\x32\'.oak9.tython.gcp.dns.DnsPolicyXNetworks\x12\x39\n\x08timeouts\x18\t \x01(\x0b\x32\'.oak9.tython.gcp.dns.DnsPolicyXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"C\n\x1e\x44nsRecordSetXRoutingPolicyXGeo\x12\x10\n\x08location\x18\x01 \x01(\t\x12\x0f\n\x07rrdatas\x18\x02 \x03(\t\"A\n\x1e\x44nsRecordSetXRoutingPolicyXWrr\x12\x0f\n\x07rrdatas\x18\x01 \x03(\t\x12\x0e\n\x06weight\x18\x02 \x01(\x01\"\xa0\x01\n\x1a\x44nsRecordSetXRoutingPolicy\x12@\n\x03geo\x18\x01 \x03(\x0b\x32\x33.oak9.tython.gcp.dns.DnsRecordSetXRoutingPolicyXGeo\x12@\n\x03wrr\x18\x02 \x03(\x0b\x32\x33.oak9.tython.gcp.dns.DnsRecordSetXRoutingPolicyXWrr\"\xfd\x01\n\x0c\x44nsRecordSet\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0cmanaged_zone\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0f\n\x07rrdatas\x18\x05 \x03(\t\x12\x0b\n\x03ttl\x18\x06 \x01(\x01\x12\x0c\n\x04type\x18\x07 \x01(\t\x12G\n\x0erouting_policy\x18\x08 \x01(\x0b\x32/.oak9.tython.gcp.dns.DnsRecordSetXRoutingPolicy\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_dns_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DNSMANAGEDZONE_LABELSENTRY._options = None
  _DNSMANAGEDZONE_LABELSENTRY._serialized_options = b'8\001'
  _DNSMANAGEDZONEXDNSSECCONFIGXDEFAULTKEYSPECS._serialized_start=63
  _DNSMANAGEDZONEXDNSSECCONFIGXDEFAULTKEYSPECS._serialized_end=179
  _DNSMANAGEDZONEXDNSSECCONFIG._serialized_start=182
  _DNSMANAGEDZONEXDNSSECCONFIG._serialized_end=356
  _DNSMANAGEDZONEXFORWARDINGCONFIGXTARGETNAMESERVERS._serialized_start=358
  _DNSMANAGEDZONEXFORWARDINGCONFIGXTARGETNAMESERVERS._serialized_end=456
  _DNSMANAGEDZONEXFORWARDINGCONFIG._serialized_start=459
  _DNSMANAGEDZONEXFORWARDINGCONFIG._serialized_end=593
  _DNSMANAGEDZONEXPEERINGCONFIGXTARGETNETWORK._serialized_start=595
  _DNSMANAGEDZONEXPEERINGCONFIGXTARGETNETWORK._serialized_end=660
  _DNSMANAGEDZONEXPEERINGCONFIG._serialized_start=662
  _DNSMANAGEDZONEXPEERINGCONFIG._serialized_end=781
  _DNSMANAGEDZONEXPRIVATEVISIBILITYCONFIGXNETWORKS._serialized_start=783
  _DNSMANAGEDZONEXPRIVATEVISIBILITYCONFIGXNETWORKS._serialized_end=853
  _DNSMANAGEDZONEXPRIVATEVISIBILITYCONFIG._serialized_start=856
  _DNSMANAGEDZONEXPRIVATEVISIBILITYCONFIG._serialized_end=984
  _DNSMANAGEDZONEXTIMEOUTS._serialized_start=986
  _DNSMANAGEDZONEXTIMEOUTS._serialized_end=1059
  _DNSMANAGEDZONE._serialized_start=1062
  _DNSMANAGEDZONE._serialized_end=1831
  _DNSMANAGEDZONE_LABELSENTRY._serialized_start=1786
  _DNSMANAGEDZONE_LABELSENTRY._serialized_end=1831
  _DNSPOLICYXALTERNATIVENAMESERVERCONFIGXTARGETNAMESERVERS._serialized_start=1833
  _DNSPOLICYXALTERNATIVENAMESERVERCONFIGXTARGETNAMESERVERS._serialized_end=1937
  _DNSPOLICYXALTERNATIVENAMESERVERCONFIG._serialized_start=1940
  _DNSPOLICYXALTERNATIVENAMESERVERCONFIG._serialized_end=2086
  _DNSPOLICYXNETWORKS._serialized_start=2088
  _DNSPOLICYXNETWORKS._serialized_end=2129
  _DNSPOLICYXTIMEOUTS._serialized_start=2131
  _DNSPOLICYXTIMEOUTS._serialized_end=2199
  _DNSPOLICY._serialized_start=2202
  _DNSPOLICY._serialized_end=2611
  _DNSRECORDSETXROUTINGPOLICYXGEO._serialized_start=2613
  _DNSRECORDSETXROUTINGPOLICYXGEO._serialized_end=2680
  _DNSRECORDSETXROUTINGPOLICYXWRR._serialized_start=2682
  _DNSRECORDSETXROUTINGPOLICYXWRR._serialized_end=2747
  _DNSRECORDSETXROUTINGPOLICY._serialized_start=2750
  _DNSRECORDSETXROUTINGPOLICY._serialized_end=2910
  _DNSRECORDSET._serialized_start=2913
  _DNSRECORDSET._serialized_end=3166
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_lambda.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x61ws/aws_lambda.proto\x12\x16oak9.tython.aws.lambda\x1a\x13shared/shared.proto\"\x8e\x01\n(AliasProvisionedConcurrencyConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12)\n!provisioned_concurrent_executions\x18\x02 \x01(\x05\"\x80\x01\n\x12\x41liasVersionWeight\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x66unction_version\x18\x02 \x01(\t\x12\x17\n\x0f\x66unction_weight\x18\x03 \x01(\x01\"\xa9\x01\n\x1e\x41liasAliasRoutingConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12N\n\x1a\x61\x64\x64itional_version_weights\x18\x02 \x03(\x0b\x32*.oak9.tython.aws.lambda.AliasVersionWeight\"\xce\x02\n\x05\x41lias\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x15\n\rfunction_name\x18\x03 \x01(\t\x12\x18\n\x10\x66unction_version\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12h\n\x1eprovisioned_concurrency_config\x18\x06 \x01(\x0b\x32@.oak9.tython.aws.lambda.AliasProvisionedConcurrencyConfiguration\x12N\n\x0erouting_config\x18\x07 \x01(\x0b\x32\x36.oak9.tython.aws.lambda.AliasAliasRoutingConfiguration\"\xf5\x03\n\x06Lambda\x12,\n\x05\x61lias\x18\x01 \x01(\x0b\x32\x1d.oak9.tython.aws.lambda.Alias\x12\x46\n\x13\x65vent_invoke_config\x18\x02 \x01(\x0b\x32).oak9.tython.aws.lambda.EventInvokeConfig\x12H\n\x14\x65vent_source_mapping\x18\x03 \x01(\x0b\x32*.oak9.tython.aws.lambda.EventSourceMapping\x12\x32\n\x08\x66unction\x18\x04 \x01(\x0b\x32 .oak9.tython.aws.lambda.Function\x12;\n\rlayer_version\x18\x05 \x01(\x0b\x32$.oak9.tython.aws.lambda.LayerVersion\x12P\n\x18layer_version_permission\x18\x06 \x01(\x0b\x32..oak9.tython.aws.lambda.LayerVersionPermission\x12\x36\n\npermission\x18\x07 \x01(\x0b\x32\".oak9.tython.aws.lambda.Permission\x12\x30\n\x07version\x18\x08 \x01(\x0b\x32\x1f.oak9.tython.aws.lambda.Version\"j\n\x1a\x45ventInvokeConfigOnSuccess\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65stination\x18\x02 \x01(\t\"j\n\x1a\x45ventInvokeConfigOnFailure\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65stination\x18\x02 \x01(\t\"\xed\x01\n\"EventInvokeConfigDestinationConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x46\n\non_success\x18\x02 \x01(\x0b\x32\x32.oak9.tython.aws.lambda.EventInvokeConfigOnSuccess\x12\x46\n\non_failure\x18\x03 \x01(\x0b\x32\x32.oak9.tython.aws.lambda.EventInvokeConfigOnFailure\"\x94\x02\n\x11\x45ventInvokeConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rfunction_name\x18\x02 \x01(\t\x12\x1e\n\x16maximum_retry_attempts\x18\x03 \x01(\x05\x12V\n\x12\x64\x65stination_config\x18\x04 \x01(\x0b\x32:.oak9.tython.aws.lambda.EventInvokeConfigDestinationConfig\x12\x11\n\tqualifier\x18\x05 \x01(\t\x12$\n\x1cmaximum_event_age_in_seconds\x18\x06 \x01(\x05\"k\n\x1b\x45ventSourceMappingOnFailure\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65stination\x18\x02 \x01(\t\"\xa7\x01\n#EventSourceMappingDestinationConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12G\n\non_failure\x18\x02 \x01(\x0b\x32\x33.oak9.tython.aws.lambda.EventSourceMappingOnFailure\"\xe2\x03\n\x12\x45ventSourceMapping\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nbatch_size\x18\x02 \x01(\x05\x12&\n\x1e\x62isect_batch_on_function_error\x18\x03 \x01(\x08\x12W\n\x12\x64\x65stination_config\x18\x04 \x01(\x0b\x32;.oak9.tython.aws.lambda.EventSourceMappingDestinationConfig\x12\x0f\n\x07\x65nabled\x18\x05 \x01(\x08\x12\x18\n\x10\x65vent_source_arn\x18\x06 \x01(\t\x12\x15\n\rfunction_name\x18\x07 \x01(\t\x12*\n\"maximum_batching_window_in_seconds\x18\x08 \x01(\x05\x12%\n\x1dmaximum_record_age_in_seconds\x18\t \x01(\x05\x12\x1e\n\x16maximum_retry_attempts\x18\n \x01(\x05\x12\x1e\n\x16parallelization_factor\x18\x0b \x01(\x05\x12\x19\n\x11starting_position\x18\x0c \x01(\t\x12\x0e\n\x06topics\x18\r \x03(\t\"\xaa\x01\n\x0c\x46unctionCode\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\ts3_bucket\x18\x02 \x01(\t\x12\x0e\n\x06s3_key\x18\x03 \x01(\t\x12\x19\n\x11s3_object_version\x18\x04 \x01(\t\x12\x10\n\x08zip_file\x18\x05 \x01(\t\x12\x11\n\timage_uri\x18\x06 \x01(\t\"g\n\x18\x46unctionDeadLetterConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ntarget_arn\x18\x02 \x01(\t\"\xde\x01\n\x13\x46unctionEnvironment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\tvariables\x18\x02 \x03(\x0b\x32:.oak9.tython.aws.lambda.FunctionEnvironment.VariablesEntry\x12\r\n\x05\x65rror\x18\x03 \x01(\t\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"z\n\x18\x46unctionFileSystemConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12\x18\n\x10local_mount_path\x18\x03 \x01(\t\"^\n\x15\x46unctionTracingConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04mode\x18\x02 \x01(\t\"\x8c\x01\n\x11\x46unctionVpcConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12security_group_ids\x18\x02 \x03(\t\x12\x12\n\nsubnet_ids\x18\x03 \x03(\t\x12\x0e\n\x06vpc_id\x18\x04 \x01(\t\"\x8b\x07\n\x08\x46unction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x32\n\x04\x63ode\x18\x02 \x01(\x0b\x32$.oak9.tython.aws.lambda.FunctionCode\x12L\n\x12\x64\x65\x61\x64_letter_config\x18\x03 \x01(\x0b\x32\x30.oak9.tython.aws.lambda.FunctionDeadLetterConfig\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12@\n\x0b\x65nvironment\x18\x05 \x01(\x0b\x32+.oak9.tython.aws.lambda.FunctionEnvironment\x12M\n\x13\x66ile_system_configs\x18\x06 \x03(\x0b\x32\x30.oak9.tython.aws.lambda.FunctionFileSystemConfig\x12\x15\n\rfunction_name\x18\x07 \x01(\t\x12\x0f\n\x07handler\x18\x08 \x01(\t\x12\x13\n\x0bkms_key_arn\x18\t \x01(\t\x12\x0e\n\x06layers\x18\n \x03(\t\x12\x13\n\x0bmemory_size\x18\x0b \x01(\x05\x12&\n\x1ereserved_concurrent_executions\x18\x0c \x01(\x05\x12\x0c\n\x04role\x18\r \x01(\t\x12\x0f\n\x07runtime\x18\x0e \x01(\t\x12\x38\n\x04tags\x18\x0f \x03(\x0b\x32*.oak9.tython.aws.lambda.Function.TagsEntry\x12\x0f\n\x07timeout\x18\x10 \x01(\x05\x12\x45\n\x0etracing_config\x18\x11 \x01(\x0b\x32-.oak9.tython.aws.lambda.FunctionTracingConfig\x12=\n\nvpc_config\x18\x12 \x01(\x0b\x32).oak9.tython.aws.lambda.FunctionVpcConfig\x12\x13\n\x0brevision_id\x18\x13 \x01(\t\x12\x12\n\nmaster_arn\x18\x14 \x01(\t\x12\x0f\n\x07version\x18\x15 \x01(\t\x12\x15\n\rlast_modified\x18\x16 \x01(\t\x12\x11\n\tcode_size\x18\x17 \x01(\t\x12\x13\n\x0b\x63ode_sha256\x18\x18 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc6\x01\n\x13LayerVersionContent\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11s3_object_version\x18\x02 \x01(\t\x12\x11\n\ts3_bucket\x18\x03 \x01(\t\x12\x0e\n\x06s3_key\x18\x04 \x01(\t\x12\x13\n\x0b\x63ode_sha256\x18\x05 \x01(\t\x12\x11\n\tcode_size\x18\x06 \x01(\t\x12\x10\n\x08location\x18\x07 \x01(\t\"\xb6\x02\n\x0cLayerVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x63ompatible_runtimes\x18\x02 \x03(\t\x12\x14\n\x0clicense_info\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x12\n\nlayer_name\x18\x05 \x01(\t\x12<\n\x07\x63ontent\x18\x06 \x01(\x0b\x32+.oak9.tython.aws.lambda.LayerVersionContent\x12\x11\n\tlayer_arn\x18\x07 \x01(\t\x12\x19\n\x11layer_version_arn\x18\x08 \x01(\t\x12\x0f\n\x07version\x18\t \x01(\t\x12\x14\n\x0c\x63reated_date\x18\n \x01(\t\"\xa8\x01\n\x16LayerVersionPermission\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12\x19\n\x11layer_version_arn\x18\x03 \x01(\t\x12\x17\n\x0forganization_id\x18\x04 \x01(\t\x12\x11\n\tprincipal\x18\x05 \x01(\t\"\xc7\x01\n\nPermission\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12\x1a\n\x12\x65vent_source_token\x18\x03 \x01(\t\x12\x15\n\rfunction_name\x18\x04 \x01(\t\x12\x11\n\tprincipal\x18\x05 \x01(\t\x12\x16\n\x0esource_account\x18\x06 \x01(\t\x12\x12\n\nsource_arn\x18\x07 \x01(\t\"\x90\x01\n*VersionProvisionedConcurrencyConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12)\n!provisioned_concurrent_executions\x18\x02 \x01(\x05\"\xef\x01\n\x07Version\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x63ode_sha256\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x15\n\rfunction_name\x18\x04 \x01(\t\x12j\n\x1eprovisioned_concurrency_config\x18\x05 \x01(\x0b\x32\x42.oak9.tython.aws.lambda.VersionProvisionedConcurrencyConfigurationb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_lambda_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FUNCTIONENVIRONMENT_VARIABLESENTRY._options = None
  _FUNCTIONENVIRONMENT_VARIABLESENTRY._serialized_options = b'8\001'
  _FUNCTION_TAGSENTRY._options = None
  _FUNCTION_TAGSENTRY._serialized_options = b'8\001'
  _ALIASPROVISIONEDCONCURRENCYCONFIGURATION._serialized_start=70
  _ALIASPROVISIONEDCONCURRENCYCONFIGURATION._serialized_end=212
  _ALIASVERSIONWEIGHT._serialized_start=215
  _ALIASVERSIONWEIGHT._serialized_end=343
  _ALIASALIASROUTINGCONFIGURATION._serialized_start=346
  _ALIASALIASROUTINGCONFIGURATION._serialized_end=515
  _ALIAS._serialized_start=518
  _ALIAS._serialized_end=852
  _LAMBDA._serialized_start=855
  _LAMBDA._serialized_end=1356
  _EVENTINVOKECONFIGONSUCCESS._serialized_start=1358
  _EVENTINVOKECONFIGONSUCCESS._serialized_end=1464
  _EVENTINVOKECONFIGONFAILURE._serialized_start=1466
  _EVENTINVOKECONFIGONFAILURE._serialized_end=1572
  _EVENTINVOKECONFIGDESTINATIONCONFIG._serialized_start=1575
  _EVENTINVOKECONFIGDESTINATIONCONFIG._serialized_end=1812
  _EVENTINVOKECONFIG._serialized_start=1815
  _EVENTINVOKECONFIG._serialized_end=2091
  _EVENTSOURCEMAPPINGONFAILURE._serialized_start=2093
  _EVENTSOURCEMAPPINGONFAILURE._serialized_end=2200
  _EVENTSOURCEMAPPINGDESTINATIONCONFIG._serialized_start=2203
  _EVENTSOURCEMAPPINGDESTINATIONCONFIG._serialized_end=2370
  _EVENTSOURCEMAPPING._serialized_start=2373
  _EVENTSOURCEMAPPING._serialized_end=2855
  _FUNCTIONCODE._serialized_start=2858
  _FUNCTIONCODE._serialized_end=3028
  _FUNCTIONDEADLETTERCONFIG._serialized_start=3030
  _FUNCTIONDEADLETTERCONFIG._serialized_end=3133
  _FUNCTIONENVIRONMENT._serialized_start=3136
  _FUNCTIONENVIRONMENT._serialized_end=3358
  _FUNCTIONENVIRONMENT_VARIABLESENTRY._serialized_start=3310
  _FUNCTIONENVIRONMENT_VARIABLESENTRY._serialized_end=3358
  _FUNCTIONFILESYSTEMCONFIG._serialized_start=3360
  _FUNCTIONFILESYSTEMCONFIG._serialized_end=3482
  _FUNCTIONTRACINGCONFIG._serialized_start=3484
  _FUNCTIONTRACINGCONFIG._serialized_end=3578
  _FUNCTIONVPCCONFIG._serialized_start=3581
  _FUNCTIONVPCCONFIG._serialized_end=3721
  _FUNCTION._serialized_start=3724
  _FUNCTION._serialized_end=4631
  _FUNCTION_TAGSENTRY._serialized_start=4588
  _FUNCTION_TAGSENTRY._serialized_end=4631
  _LAYERVERSIONCONTENT._serialized_start=4634
  _LAYERVERSIONCONTENT._serialized_end=4832
  _LAYERVERSION._serialized_start=4835
  _LAYERVERSION._serialized_end=5145
  _LAYERVERSIONPERMISSION._serialized_start=5148
  _LAYERVERSIONPERMISSION._serialized_end=5316
  _PERMISSION._serialized_start=5319
  _PERMISSION._serialized_end=5518
  _VERSIONPROVISIONEDCONCURRENCYCONFIGURATION._serialized_start=5521
  _VERSIONPROVISIONEDCONCURRENCYCONFIGURATION._serialized_end=5665
  _VERSION._serialized_start=5668
  _VERSION._serialized_end=5907
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ResourceManagerLienXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ResourceManagerLienXTimeouts = ResourceManagerLienXTimeouts

@typing_extensions.final
class ResourceManagerLien(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORIGIN_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    RESTRICTIONS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    id: builtins.str
    name: builtins.str
    origin: builtins.str
    parent: builtins.str
    reason: builtins.str
    @property
    def restrictions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def timeouts(self) -> global___ResourceManagerLienXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        origin: builtins.str = ...,
        parent: builtins.str = ...,
        reason: builtins.str = ...,
        restrictions: collections.abc.Iterable[builtins.str] | None = ...,
        timeouts: global___ResourceManagerLienXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "id", b"id", "name", b"name", "origin", b"origin", "parent", b"parent", "reason", b"reason", "resource_info", b"resource_info", "restrictions", b"restrictions", "timeouts", b"timeouts"]) -> None: ...

global___ResourceManagerLien = ResourceManagerLien



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.apimachinery.pkg.version.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;kubernetes/kubernetes_io.k8s.apimachinery.pkg.version.proto\x12(oak9.tython.k8s.apimachinery.pkg.version\x1a\x13shared/shared.proto\"\xea\x01\n\x04Info\x12\x12\n\nbuild_date\x18\x01 \x01(\t\x12\x10\n\x08\x63ompiler\x18\x02 \x01(\t\x12\x12\n\ngit_commit\x18\x03 \x01(\t\x12\x16\n\x0egit_tree_state\x18\x04 \x01(\t\x12\x13\n\x0bgit_version\x18\x05 \x01(\t\x12\x12\n\ngo_version\x18\x06 \x01(\t\x12\r\n\x05major\x18\x07 \x01(\t\x12\r\n\x05minor\x18\x08 \x01(\t\x12\x10\n\x08platform\x18\t \x01(\t\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.apimachinery.pkg.version_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INFO._serialized_start=127
  _INFO._serialized_end=361
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_elasticbeanstalk.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61ws/aws_elasticbeanstalk.proto\x12 oak9.tython.aws.elasticbeanstalk\x1a\x13shared/shared.proto\"\x99\x01\n\x15\x41pplicationMaxAgeRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x64\x65lete_source_from_s3\x18\x02 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\x17\n\x0fmax_age_in_days\x18\x04 \x01(\x05\"\x95\x01\n\x17\x41pplicationMaxCountRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x64\x65lete_source_from_s3\x18\x02 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\x11\n\tmax_count\x18\x04 \x01(\x05\"\x89\x02\n,ApplicationApplicationVersionLifecycleConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x0cmax_age_rule\x18\x02 \x01(\x0b\x32\x37.oak9.tython.aws.elasticbeanstalk.ApplicationMaxAgeRule\x12Q\n\x0emax_count_rule\x18\x03 \x01(\x0b\x32\x39.oak9.tython.aws.elasticbeanstalk.ApplicationMaxCountRule\"\xf0\x01\n-ApplicationApplicationResourceLifecycleConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cservice_role\x18\x02 \x01(\t\x12p\n\x18version_lifecycle_config\x18\x03 \x01(\x0b\x32N.oak9.tython.aws.elasticbeanstalk.ApplicationApplicationVersionLifecycleConfig\"\xe9\x01\n\x0b\x41pplication\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12r\n\x19resource_lifecycle_config\x18\x04 \x01(\x0b\x32O.oak9.tython.aws.elasticbeanstalk.ApplicationApplicationResourceLifecycleConfig\"\xc6\x02\n\x10\x45lasticBeanstalk\x12\x42\n\x0b\x61pplication\x18\x01 \x01(\x0b\x32-.oak9.tython.aws.elasticbeanstalk.Application\x12Q\n\x13\x61pplication_version\x18\x02 \x03(\x0b\x32\x34.oak9.tython.aws.elasticbeanstalk.ApplicationVersion\x12W\n\x16\x63onfiguration_template\x18\x03 \x01(\x0b\x32\x37.oak9.tython.aws.elasticbeanstalk.ConfigurationTemplate\x12\x42\n\x0b\x65nvironment\x18\x04 \x03(\x0b\x32-.oak9.tython.aws.elasticbeanstalk.Environment\"|\n\x1e\x41pplicationVersionSourceBundle\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\ts3_bucket\x18\x02 \x01(\t\x12\x0e\n\x06s3_key\x18\x03 \x01(\t\"\xd5\x01\n\x12\x41pplicationVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12W\n\rsource_bundle\x18\x04 \x01(\x0b\x32@.oak9.tython.aws.elasticbeanstalk.ApplicationVersionSourceBundle\"\xb8\x01\n/ConfigurationTemplateConfigurationOptionSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x13\n\x0boption_name\x18\x03 \x01(\t\x12\x15\n\rresource_name\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\t\"\x94\x01\n(ConfigurationTemplateSourceConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12\x15\n\rtemplate_name\x18\x03 \x01(\t\"\xa0\x03\n\x15\x43onfigurationTemplate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x04 \x01(\t\x12j\n\x0foption_settings\x18\x05 \x03(\x0b\x32Q.oak9.tython.aws.elasticbeanstalk.ConfigurationTemplateConfigurationOptionSetting\x12\x14\n\x0cplatform_arn\x18\x06 \x01(\t\x12\x1b\n\x13solution_stack_name\x18\x07 \x01(\t\x12h\n\x14source_configuration\x18\x08 \x01(\x0b\x32J.oak9.tython.aws.elasticbeanstalk.ConfigurationTemplateSourceConfiguration\"\xa1\x01\n\x18\x45nvironmentOptionSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x13\n\x0boption_name\x18\x03 \x01(\t\x12\x15\n\rresource_name\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\t\"i\n\x0f\x45nvironmentTier\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\"\x90\x04\n\x0b\x45nvironment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pplication_name\x18\x02 \x01(\t\x12\x14\n\x0c\x63name_prefix\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x18\n\x10\x65nvironment_name\x18\x05 \x01(\t\x12S\n\x0foption_settings\x18\x06 \x03(\x0b\x32:.oak9.tython.aws.elasticbeanstalk.EnvironmentOptionSetting\x12\x14\n\x0cplatform_arn\x18\x07 \x01(\t\x12\x1b\n\x13solution_stack_name\x18\x08 \x01(\t\x12\x45\n\x04tags\x18\t \x03(\x0b\x32\x37.oak9.tython.aws.elasticbeanstalk.Environment.TagsEntry\x12\x15\n\rtemplate_name\x18\n \x01(\t\x12?\n\x04tier\x18\x0b \x01(\x0b\x32\x31.oak9.tython.aws.elasticbeanstalk.EnvironmentTier\x12\x15\n\rversion_label\x18\x0c \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_elasticbeanstalk_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ENVIRONMENT_TAGSENTRY._options = None
  _ENVIRONMENT_TAGSENTRY._serialized_options = b'8\001'
  _APPLICATIONMAXAGERULE._serialized_start=90
  _APPLICATIONMAXAGERULE._serialized_end=243
  _APPLICATIONMAXCOUNTRULE._serialized_start=246
  _APPLICATIONMAXCOUNTRULE._serialized_end=395
  _APPLICATIONAPPLICATIONVERSIONLIFECYCLECONFIG._serialized_start=398
  _APPLICATIONAPPLICATIONVERSIONLIFECYCLECONFIG._serialized_end=663
  _APPLICATIONAPPLICATIONRESOURCELIFECYCLECONFIG._serialized_start=666
  _APPLICATIONAPPLICATIONRESOURCELIFECYCLECONFIG._serialized_end=906
  _APPLICATION._serialized_start=909
  _APPLICATION._serialized_end=1142
  _ELASTICBEANSTALK._serialized_start=1145
  _ELASTICBEANSTALK._serialized_end=1471
  _APPLICATIONVERSIONSOURCEBUNDLE._serialized_start=1473
  _APPLICATIONVERSIONSOURCEBUNDLE._serialized_end=1597
  _APPLICATIONVERSION._serialized_start=1600
  _APPLICATIONVERSION._serialized_end=1813
  _CONFIGURATIONTEMPLATECONFIGURATIONOPTIONSETTING._serialized_start=1816
  _CONFIGURATIONTEMPLATECONFIGURATIONOPTIONSETTING._serialized_end=2000
  _CONFIGURATIONTEMPLATESOURCECONFIGURATION._serialized_start=2003
  _CONFIGURATIONTEMPLATESOURCECONFIGURATION._serialized_end=2151
  _CONFIGURATIONTEMPLATE._serialized_start=2154
  _CONFIGURATIONTEMPLATE._serialized_end=2570
  _ENVIRONMENTOPTIONSETTING._serialized_start=2573
  _ENVIRONMENTOPTIONSETTING._serialized_end=2734
  _ENVIRONMENTTIER._serialized_start=2736
  _ENVIRONMENTTIER._serialized_end=2841
  _ENVIRONMENT._serialized_start=2844
  _ENVIRONMENT._serialized_end=3372
  _ENVIRONMENT_TAGSENTRY._serialized_start=3329
  _ENVIRONMENT_TAGSENTRY._serialized_end=3372
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_recaptcha.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gcp/gcp_recaptcha.proto\x12\x19oak9.tython.gcp.recaptcha\x1a\x13shared/shared.proto\"h\n&RecaptchaEnterpriseKeyXAndroidSettings\x12\x1f\n\x17\x61llow_all_package_names\x18\x01 \x01(\x08\x12\x1d\n\x15\x61llowed_package_names\x18\x02 \x03(\t\"^\n\"RecaptchaEnterpriseKeyXIosSettings\x12\x1c\n\x14\x61llow_all_bundle_ids\x18\x01 \x01(\x08\x12\x1a\n\x12\x61llowed_bundle_ids\x18\x02 \x03(\t\"Y\n%RecaptchaEnterpriseKeyXTestingOptions\x12\x19\n\x11testing_challenge\x18\x01 \x01(\t\x12\x15\n\rtesting_score\x18\x02 \x01(\x01\"Q\n\x1fRecaptchaEnterpriseKeyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb4\x01\n\"RecaptchaEnterpriseKeyXWebSettings\x12\x19\n\x11\x61llow_all_domains\x18\x01 \x01(\x08\x12\x19\n\x11\x61llow_amp_traffic\x18\x02 \x01(\x08\x12\x17\n\x0f\x61llowed_domains\x18\x03 \x03(\t\x12%\n\x1d\x63hallenge_security_preference\x18\x04 \x01(\t\x12\x18\n\x10integration_type\x18\x05 \x01(\t\"\xd5\x05\n\x16RecaptchaEnterpriseKey\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12M\n\x06labels\x18\x04 \x03(\x0b\x32=.oak9.tython.gcp.recaptcha.RecaptchaEnterpriseKey.LabelsEntry\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12[\n\x10\x61ndroid_settings\x18\x07 \x01(\x0b\x32\x41.oak9.tython.gcp.recaptcha.RecaptchaEnterpriseKeyXAndroidSettings\x12S\n\x0cios_settings\x18\x08 \x01(\x0b\x32=.oak9.tython.gcp.recaptcha.RecaptchaEnterpriseKeyXIosSettings\x12Y\n\x0ftesting_options\x18\t \x01(\x0b\x32@.oak9.tython.gcp.recaptcha.RecaptchaEnterpriseKeyXTestingOptions\x12L\n\x08timeouts\x18\n \x01(\x0b\x32:.oak9.tython.gcp.recaptcha.RecaptchaEnterpriseKeyXTimeouts\x12S\n\x0cweb_settings\x18\x0b \x01(\x0b\x32=.oak9.tython.gcp.recaptcha.RecaptchaEnterpriseKeyXWebSettings\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_recaptcha_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RECAPTCHAENTERPRISEKEY_LABELSENTRY._options = None
  _RECAPTCHAENTERPRISEKEY_LABELSENTRY._serialized_options = b'8\001'
  _RECAPTCHAENTERPRISEKEYXANDROIDSETTINGS._serialized_start=75
  _RECAPTCHAENTERPRISEKEYXANDROIDSETTINGS._serialized_end=179
  _RECAPTCHAENTERPRISEKEYXIOSSETTINGS._serialized_start=181
  _RECAPTCHAENTERPRISEKEYXIOSSETTINGS._serialized_end=275
  _RECAPTCHAENTERPRISEKEYXTESTINGOPTIONS._serialized_start=277
  _RECAPTCHAENTERPRISEKEYXTESTINGOPTIONS._serialized_end=366
  _RECAPTCHAENTERPRISEKEYXTIMEOUTS._serialized_start=368
  _RECAPTCHAENTERPRISEKEYXTIMEOUTS._serialized_end=449
  _RECAPTCHAENTERPRISEKEYXWEBSETTINGS._serialized_start=452
  _RECAPTCHAENTERPRISEKEYXWEBSETTINGS._serialized_end=632
  _RECAPTCHAENTERPRISEKEY._serialized_start=635
  _RECAPTCHAENTERPRISEKEY._serialized_end=1360
  _RECAPTCHAENTERPRISEKEY_LABELSENTRY._serialized_start=1315
  _RECAPTCHAENTERPRISEKEY_LABELSENTRY._serialized_end=1360
# @@protoc_insertion_point(module_scope)
